# 版本号：1
# 请切记数据库更新（应用版本更新）的时候不要在原来的版本文件里修改，原来的文件不能有任何修改
# 新加的数据库写在新的数据库版本文件里

# -------------------------------- AccountSimple --------------------------------
# desc 用户账号详细信息，这里包括好友，好友推荐，好友请求，陌生人聊天等产生的所有用户账号信息，并且永远不会删除
# param accountID 用户账号ID
# param surName 姓
# param nickName 名称
# param zugaID 
# param profile 头像URL地址
# param gender 性别 0=女 1=男
# param birthday yyyy-MM-dd 格式的字符串
# param marriage 情感状态
# param signinTime 注册时间戳，毫秒为单位

CREATE TABLE IF NOT EXISTS `AccountSimple`(
	`accountID` BIGINT NOT NULL PRIMARY KEY,
    `surName` VARCHAR(255) NULL,
    `nickName` VARCHAR(255) NOT NULL,
    `zugaID` VARCHAR(50) NULL,
    `profile` VARCHAR(255) NULL,
    `gender` TINYINT NOT NULL,
    `birthday` CHAR(10) NULL,
    `marriage` TINYINT NOT NULL,
    `signinTime` BIGINT NOT NULL,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);
CREATE INDEX `account_simple_nick_name` ON `AccountSimple`(`nickName`);

# -------------------------------- Group --------------------------------
# desc 群聊详细信息
# param groupID 群ID
# param name 群聊名称
# param profile 群头像，默认空
# param creater 群创建者
# param members 群聊中用户的ID列表，用逗号分隔
# param alert 是否提示信息 0=否 1=是

CREATE TABLE IF NOT EXISTS `Group`(
	`groupID` BIGINT NOT NULL PRIMARY KEY,
    `name` VARCHAR(255) NULL,
    `profile` VARCHAR(255) NULL,
    `creater` BIGINT NOT NULL,
    `members` TEXT,
    `alert` TINYINT DEFAULT 1,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);

# -------------------------------- Official --------------------------------
# desc 官方账号，此表不删除数据
# param officialID 官方账号ID
# param nickName 官方账号名称
# param profile 官方账号头像URL地址
# param introduction 官方账号介绍

CREATE TABLE IF NOT EXISTS `Official`(
	`officialID` BIGINT NOT NULL PRIMARY KEY,
    `nickName` VARCHAR(255) NOT NULL,
    `profile` VARCHAR(255) NULL,
    `introduction` TEXT,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);

# -------------------------------- Friend --------------------------------
# desc 好友列表
# param accountID 好友ID
# param read 0=未读 1=已读 显示未读在最前面，点击打开好友列表时全部设置未已读

CREATE TABLE IF NOT EXISTS `Friend`(
	`accountID` BIGINT NOT NULL PRIMARY KEY,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);

# -------------------------------- FriendRequest --------------------------------
# desc 好友请求列表
# param accountID 请求发送者用户ID
# param accepted 0=未接受 1=已接受

CREATE TABLE IF NOT EXISTS `FriendRequest`(
	`accountID` BIGINT NOT NULL PRIMARY KEY,
    `accepted` TINYINT DEFAULT 0,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);
CREATE INDEX `friend_request_create_time` ON `FriendRequest`(`createTime`);

# -------------------------------- FriendRecommend --------------------------------
# desc 好友推荐列表，添加好友成功之后需要删除相应的推荐
# param accountID 被推荐用户的ID
# param reason 推荐描述或理由
# param requested 状态 0=未发送请求 1=已发送请求

CREATE TABLE IF NOT EXISTS `FriendRecommend`(
	`accountID` BIGINT NOT NULL PRIMARY KEY,
    `reason` TEXT,
    `requested` TINYINT DEFAULT 0,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);
CREATE INDEX `friend_recommend_create_time` ON `FriendRecommend`(`createTime`);

# -------------------------------- Message --------------------------------
# desc 消息列表，保存所有会话消息
# param messageID 自增长主键
# param messageType 消息类型 0=文字（包括系统提醒） 1=语音 2=图片 3=名片
# param messageContent 消息内容：文字，语音URL地址，图片URL地址，名片类型和ID的json串
# param sessionType 会话类型 0=official 1=account 2=group
# param sessionValue 会话ID 官方账号ID，用户账号ID，群ID
# param senderID 发送者ID，官方账号ID，用户账号ID，群时发送者用户ID，空表示系统消息
# param action 0=发送的消息 1=接受的消息
# param style 样式 0=default 1=boy 2=girl 用户充值之后启用1和2
# param status 消息状态，只对发送的消息有效 0=正在发送，1=发送成功 2=发送失败
# param read 是否已读，对语音消息有效
# param timestamp 消息发送时间戳（毫秒）
# param args 消息的其他参数，例如语音消息的时长、图片的大小等，每个客户端根据自己的需求组织数据

CREATE TABLE IF NOT EXISTS `Message`(
	`messageID` INTEGER PRIMARY KEY AUTOINCREMENT,
    `messageType` TINYINT DEFAULT 0,
    `messageContent` TEXT,
    `sessionType` TINYINT NOT NULL,
    `sessionValue` BITINT NOT NULL,
    `senderID` BIGINT NULL,
    `action` TINYINT DEFAULT 0,
    `style` TINYINT DEFAULT 0,
    `status` TINYINT DEFAULT 0,
    `read` TINYINT DEFAULT 0,
    `timestamp` BIGINT DEFAULT 0,
    `args` VARCHAR(255) NULL,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);
CREATE INDEX `message_session_type` ON `Message`(`sessionType`);
CREATE INDEX `message_session_value` ON `Message`(`sessionValue`);
CREATE INDEX `message_create_time` ON `Message`(`createTime`);

# -------------------------------- Chat --------------------------------
# desc 聊天列表
# param chatID 自增长的主键
# param sessionType 会话类型 0=official 1=account 2=group
# param sessionValue 会话ID 账号或群ID
# param top 置顶值，0表示不置顶，数字越大排名越靠前
# param lastMessage 最后一条消息，不保存系统文字消息，语音图片和名片按插入固定的文字，比如【语音】，【图片】【名片】等，用于在聊天列表里显示最后一条消息
# param lastTime 最后一条消息的时间戳（毫秒）

CREATE TABLE IF NOT EXISTS `Chat`(
    `chatID` INTEGER PRIMARY KEY AUTOINCREMENT,
    `sessionType` TINYINT DEFAULT 0,
    `sessionValue` BIGINT NOT NULL,
    `top` BIGINT DEFAULT 0,
    `lastMessage` TEXT,
    `lastTime` BIGINT DEFAULT 0,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);
CREATE INDEX `chat_session_type` ON `Chat`(`sessionType`);
CREATE INDEX `chat_session_value` ON `Chat`(`sessionValue`);
CREATE INDEX `chat_top` ON `Chat`(`top`);
CREATE INDEX `chat_update_time` ON `Chat`(`updateTime`);

# -------------------------------- Contacts --------------------------------
# desc 手机通讯录
# param phone 手机号码
# param upload 是否已上传 0=没有上传 1=已上传

CREATE TABLE IF NOT EXISTS `Contacts`(
    `phone` VARCHAR(20) PRIMARY KEY,
    `upload` TINYINT DEFAULT 0,
	`createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);
CREATE INDEX `contacts_upload` ON `Contacts`(`upload`);

# -------------------------------- Notification --------------------------------
# desc 通知记录，用于显示红色数字
# param name 通知标签，从界面角度出发，每个位置只要显示通知数量都需要一个独一无二的标签
# param parentName 通知的父通知标签
# param basic 是否为基础通知，基础通知不能有子通知
# param count 消息数量，只对基础通知有效，非基础通知的count为所有孩子（包括孩子的孩子）的中基础通知的数量之和
# param definite 是否明确显示数字，0=不明确显示 1=明确显示  不明确显示的时候显示红点表示有新消息或通知

CREATE TABLE IF NOT EXISTS `Notification`(
    `tag` VARCHAR(255) NOT NULL PRIMARY KEY,
    `parentTag` VARCHAR(255) DEFAULT NULL,
    `basic` TINYINT DEFAULT 0,
    `count` INTEGER DEFAULT 0,
    `definite` TINYINT DEFAULT 1,
    `createTime` BIGINT DEFAULT 0,
	`updateTime` BIGINT DEFAULT 0
);
INSERT INTO `Notification` (`tag`) VALUES ('tab_chat');
INSERT INTO `Notification` (`tag`) VALUES ('tab_nearby');
INSERT INTO `Notification` (`tag`) VALUES ('tab_square');
INSERT INTO `Notification` (`tag`) VALUES ('tab_mine');
INSERT INTO `Notification` (`tag`,`parentTag`) VALUES ('nav_friend','tab_chat');
INSERT INTO `Notification` (`tag`,`parentTag`,`basic`) VALUES ('friend_recommend','nav_friend',1);
INSERT INTO `Notification` (`tag`,`parentTag`,`basic`) VALUES ('check_version','tab_mine',1);

# -------------------------------- Property --------------------------------
# desc 记录额外的属性信息
# param name 属性名称
# param content 属性内容

CREATE TABLE IF NOT EXISTS `Property`(
    `name` VARCHAR(255) PRIMARY KEY,
    `content` VARCHAR(255) NOT NULL,
    `createTime` BIGINT DEFAULT 0,
    `updateTime` BIGINT DEFAULT 0
);
